==> Avenue-0.1.5-py2.py3-none-any.whl: avenue/processors.py <==
from __future__ import absolute_import, division, print_function

from pandora import CONVERTERS
from pandora import Path


class Match(object):
    def __init__(self, score=None, kwargs=None):
        self.score = score or list()
        self.kwargs = kwargs or dict()

    def update(self, result):
        if type(result) is int:
            self.score.append(result)
        elif isinstance(result, Match):
            self.score.append(result.score)
            self.kwargs.update(result.kwargs)

    def __lt__(self, other):
        return all([s < other.score[sx] for sx, s in enumerate(self.score)])

    def __repr__(self):
        return '<Match (score={:s})>'.format(repr(self.score))


class MatchError(Exception):
    pass


class Processor(object):
    def __init__(self, name, optional=False):
        self.name = name
        self.optional = optional

    def prepare(self, value, route):
        argument = route.kwargs.get(self.name)

        if not argument and not self.optional:
            message = 'Cannot run route, `{:s}` is not optional.'.format(
                self.name)

            raise RuntimeError(message)

        if argument and value is None:
            message = 'Value not found, `{:s}` is not optional.'.format(
                self.name)

            raise MatchError(message)

        return argument, value


class PathProcessor(Processor):
    def __init__(self, name, optional=False, converters=None):
        super(PathProcessor, self).__init__(name, optional)
        self.cache = dict()
        self.converters = converters or CONVERTERS

    def __call__(self, value, route):
        """

        :type value: mixed
        :type route: avenue.Route
        :rtype: Match
        """
        argument, value = self.prepare(value, route)

        if not argument:
            return True, -100, 100

        if argument not in self.cache:
            self.cache[argument] = Path(argument, self.converters,
                                        split='/')

        path = self.cache[argument]
        match = path(value)

        if match is not None:
            return Match(path, match)

        raise MatchError('Path does not match, `{:s}` != `{:s}`'.format(
            path.original, argument))


class MethodProcessor(Processor):
    def __call__(self, value, route):
        """

        :type value: mixed
        :type route: avenue.Route
        :rtype: Match
        """
        argument, value = self.prepare(value, route)

        if not argument:
            return 0
        elif value == argument:
            return 1
        else:
            error = 'Method does not match, `{:s}` != `{:s}`'.format(
                value, argument)
            raise MatchError(error)

==> Avenue-0.2.2-py2.py3-none-any.whl: avenue/processors.py <==
# -*- coding: utf-8 -*-
from __future__ import absolute_import, division, print_function

from pandora import CONVERTERS
from pandora import Path


class Match(object):
    def __init__(self, score=None, kwargs=None):
        self.score = score or list()
        self.kwargs = kwargs or dict()

    def update(self, result):
        if type(result) is int:
            self.score.append(result)
        elif isinstance(result, Match):
            self.score.append(result.score)
            self.kwargs.update(result.kwargs)

    def __lt__(self, other):
        return any([s < other.score[sx] for sx, s in enumerate(self.score)])

    def __repr__(self):
        return '<Match (score={:s})>'.format(repr(self.score))


class MatchError(Exception):
    pass


class Processor(object):
    def __init__(self, name, optional=False):
        self.name = name
        self.optional = optional

    def prepare(self, value, route):
        argument = route.kwargs.get(self.name)

        if not argument and not self.optional:
            message = 'Cannot run route, `{:s}` is not optional.'.format(
                self.name)

            raise RuntimeError(message)

        if argument and value is None:
            message = 'Value not found, `{:s}` is not optional.'.format(
                self.name)

            raise MatchError(message)

        return argument, value

    def blueprint(self, value, blueprint_value=None):
        if blueprint_value is None:
            return value
        else:
            return blueprint_value + value


class PathProcessor(Processor):
    def __init__(self, name, optional=False, converters=None):
        super(PathProcessor, self).__init__(name, optional)
        self.cache = dict()
        self.converters = converters or CONVERTERS

    def __call__(self, value, route):
        """

        :type value: mixed
        :type route: avenue.Route
        :rtype: Match
        """
        argument, value = self.prepare(value, route)

        if not argument:
            return True, -100, 100

        if argument not in self.cache:
            self.cache[argument] = Path(argument, self.converters,
                                        split='/')

        path = self.cache[argument]
        match = path(value)

        if match is not None:
            return Match(path, match)

        raise MatchError(u'Path does not match, `{:s}` != `{:s}`'.format(
            path.original, argument))

    def blueprint(self, value, blueprint_value=None):
        if blueprint_value is None:
            return value
        elif u'§' in value:
            return value.replace(u'§', blueprint_value).replace('//', '/')
        else:
            return (blueprint_value + value).replace('//', '/')


class MethodProcessor(Processor):
    def __call__(self, value, route):
        """

        :type value: mixed
        :type route: avenue.Route
        :rtype: Match
        """
        argument, value = self.prepare(value, route)

        if not argument:
            return 0
        elif value == argument:
            return -1
        else:
            error = 'Method does not match, `{:s}` != `{:s}`'.format(
                value, argument)
            raise MatchError(error)

    def blueprint(self, value, blueprint_value=None):
        return value or blueprint_value
